@@ -24,6 +24,17 @@ bp = Blueprint(__name__)
 
 class BaseHandler(BaseHandler):
 
+    def set_default_headers(self):
+        self.set_header('Access-Control-Allow-Origin', '*')
+        self.set_header('Access-Control-Allow-Headers', '*')
+        self.set_header('Access-Control-Allow-Methods', 'POST, GET, PUT, DELETE, HEAD, OPTIONS')
+        self.set_header('Access-Control-Allow-Credentials', 'true')
+        self.set_header('Access-Control-Max-Age', '3600')
+
+    def options(self):
+        self.set_status(204)
+        self.finish()
+
     def encrypt(self, password):
         return hashlib.md5(f'digua_{password}'.encode()).hexdigest()
 
@@ -173,7 +184,7 @@ class SignupHandler(BaseHandler):
             if update:
                 await awaitable(self.db.users.update_one({'_id': ret._id}, {'$set': update}))
             self.set_cookie('token', token, expires_days=30)
-            self.finish({'err': 0})
+            self.finish({'err': 0, 'token': token})
         else:
             self.finish({'err': 1, 'msg': '信息未填写完整'})
 
@@ -196,7 +207,7 @@ class SigninHandler(BaseHandler):
                 query = {'username': username, 'password': self.encrypt(password)}
             user = await awaitable(self.db.users.find_one(query))
             if user:
-                ret = {'err': 0, 'msg': '登录成功'}
+                ret = {'err': 0, 'token': user.token}
                 if remember == 'on':
                     self.set_cookie('token', user.token, expires_days=30)
                 else:
