@@ -67,7 +67,7 @@ class PageModule(UIModule):
 
     def render(self, total, **kwargs):
         ''' Args:
-        count: how many items each page shows
+        size: how many items each page shows
         total: the total items number
         '''
         t = Template('''<nav>
@@ -88,9 +88,9 @@ class PageModule(UIModule):
     <li class="page-item disabled"><span class="page-link">{{ total }}项</span></li>
   </ul>
 </nav>''')
-        kwargs.setdefault('count', int(self.handler.get_argument('count', 20)))
+        kwargs.setdefault('size', int(self.handler.get_argument('size', 20)))
         kwargs.setdefault('page', int(self.handler.get_argument('page', 1)))
-        pages = int(math.ceil(total / kwargs['count']))
+        pages = int(math.ceil(total / kwargs['size']))
         return t.generate(pages=pages, total=total, get_url=self.get_url, **kwargs)
 
     def css_files(self):
