@@ -20,19 +20,23 @@ class WatchedFileHandler(logging.handlers.WatchedFileHandler):
 
 def Logger(filename=None, name=None, level='INFO', stream=True):
     logger = logging.getLogger(name)
+    if logger.handlers and logger.handlers[0].name == 'Logger':
+        return logger
     logger.setLevel(level.upper())
     logger.propagate = False
     logger.handlers = []
     datefmt = '%Y-%m-%d %H:%M:%S'
-    fmt = '%(color)s[%(levelname)1.1s %(asctime)s %(module)s:%(lineno)d]%(end_color)s %(message)s'
+    fmt = '%(color)s[%(levelname)s %(asctime)s %(module)s:%(lineno)d]%(end_color)s %(message)s'
     if stream:
         hdlr = logging.StreamHandler()
+        hdlr.name = 'Logger'
         hdlr.setFormatter(LogFormatter(fmt=fmt, datefmt=datefmt))
         hdlr.setLevel(level)
         logger.addHandler(hdlr)
 
     if filename:
         hdlr = logging.handlers.WatchedFileHandler(filename=filename, mode='a', encoding='utf-8')
+        hdlr.name = 'Logger'
         hdlr.setFormatter(LogFormatter(fmt=fmt, datefmt=datefmt, color=False))
         hdlr.setLevel(level)
         logger.addHandler(hdlr)
