@@ -5,8 +5,10 @@ Author: zhangkai
 Last modified: 2020-06-29 10:18:14
 '''
 import asyncio
+import sys
 from concurrent.futures._base import CancelledError
 from functools import partial
+from importlib import import_module
 from signal import SIGINT
 from signal import SIGTERM
 
@@ -76,3 +78,14 @@ class Processor:
         for _ in range(self.workers):
             self.loop.create_task(self._consumer())
         self.loop.run_until_complete(self.finish())
+
+
+def main():
+    module_name, app_name = sys.argv[1].split('.')
+    module = import_module(module_name)
+    app = getattr(module, app_name)()
+    app.start()
+
+
+if __name__ == '__main__':
+    main()
